@@ -432,7 +432,12 @@ static void show_exif(struct flist *f)
 	    continue;
 	}
 	title[tag] = exif_tag_get_title(tags[tag]);
+#ifdef HAVE_NEW_EXIF
+	value[tag] = malloc(128);
+	exif_entry_get_value(ee, value[tag], 128);
+#else
 	value[tag] = strdup(exif_entry_get_value(ee));
+#endif
 	len = strlen(title[tag]);
 	if (l1 < len)
 	    l1 = len;
@@ -1167,7 +1172,13 @@ main(int argc, char *argv[])
     need_read = 1;
 
     font_init();
-    face = font_open(fontname ? fontname : "monospace:size=16");
+    if (NULL == fontname)
+	fontname = "monospace:size=16";
+    face = font_open(fontname);
+    if (NULL == face) {
+	fprintf(stderr,"can't open font: %s\n",fontname);
+	exit(1);
+    }
     fd = fb_init(cfg_get_str(O_DEVICE),
 		 cfg_get_str(O_VIDEO_MODE),
 		 GET_VT());
